\name{panelMPL}
\alias{panelMPL}
\title{Modified Profile Likelihood estimation for fixed-effects panel data models}
\description{Estimates structural parameters  after removing panel-specific fixed effects}
\usage{ panelMPL(formula, data = list(), panel, model, method = "nm", y0 = NULL, start=NULL, R=NULL, seed=NULL) }
\arguments{
  \item{formula}{
  	symbolic description of the model (of type \code{y ~ x}.)
    }
  \item{data}{argument controlling formula processing via  \code{\link[stats]{model.frame}}.
}
  \item{panel}{panel indicator (factor or numeric).
}
  \item{model}{
  	character specification of the model. Currently, \code{"dynLogit"}, \code{"dynProbit"},
    \code{"statLogit"}, \code{"statProbit"}, \code{"truncReg"}, \code{"ar1"} are supported.
}
  \item{method}{estimation method used by \code{\link[maxLik]{maxLik}}, namely
  either "Newton-Raphson",
    "BFGS", "BFGS-YC",
    "BHHH", "SANN" or "NM" (for Nelder-Mead).  Lower-case letters and
    shortcuts (as 'nr' for Newton-Raphson) allowed. The default is \code{"NM"}.
  }
  \item{y0}{
       vector of size \eqn{N \times 1}{N x 1} with the first observation for each panel. Only used 
       for \code{"dynLogit"} or \code{"dynProbit"} models. 
}
\item{start}{optional vector of starting point for model parameters.
}
\item{R}{number of MC trials in case of Monte Carlo computation of MPL.  Default is \code{"NULL"}, 
requesting exact computation. Only for \code{"dynLogit"} or \code{"dynProbit"} models.
}
\item{seed}{optional random seed to be used for reproducible results of Monte Carlo computation of MPL. Used only if 
\code{"R"} is not NULL, and only for \code{"dynLogit"} or \code{"dynProbit"} models. 
}
}
\details{
The current version only supports the case of 
 \eqn{N}{N} balanced panels of equal size \eqn{T}{T} and performs a limited argument checking. Model fitting
is based on the \code{maxLik} package. 
}
\value{
See the object returned by the \code{\link{maxLik}} function of the \code{maxLik} package. The only additional argument
is \code{mle}, which is the vector of uncorrected maximum likelihood estimates.
}
\references{Bartolucci, F., Bellio, R., Salvan, A., Sartori, N. (2015). "Modified Profile Likelihood for Fixed-Effects Panel Data Models", 
Econometric Reviews.}


\author{
Ruggero Bellio and Nicola Sartori.
}


\seealso{
 \code{\link{maxLik}}.
}
\examples{
## Static logit  case
## Generate some data with N=500 and T=4, and two covariates
panelInd <- rep(1:500,each=4)
set.seed(123)
X <- matrix(rnorm(500 * 4 * 2), nrow=500 * 4, ncol=2)
alpha <-  tapply(X[,1],panelInd,mean) + rnorm(500)
y <- simu.panelMPL(X, panelInd, "statLogit",  beta=c(-1,2),  alpha=alpha)
obj <- panelMPL(y~X, panel=panelInd, model="statLogit")
## Compare MPL with MLE estimates
cbind(obj$mle, obj$est)
#
## Dynamic logit  case
## Generate some data with N=1000 and T=5, and no covariates
panelInd <- rep(1:1000,each=5)
set.seed(234)
y0 <- rbinom(1000, size=1, prob=1/3)
alpha <-  rt(1000,df=3)
y <- simu.panelMPL(X=matrix(1,5000,1), panelInd, "dynLogit",  beta=0, rho=1, y0=y0, alpha=alpha)
obj <- panelMPL(y~1, panel=panelInd, model="dynLogit",y0=y0,method="BFGS")  
summary(obj)  
## Compare MPL with MLE estimates
cbind(obj$mle, obj$est)
#
## Now use Monte Carlo computation of MPL
objMC <- panelMPL(y~1, panel=panelInd, model="dynLogit",y0=y0,method="BFGS",R=2000,seed=22)
summary(objMC)  
## Truncated regression
## Generate some data with N=500 and T=2, and two covariates
panelInd <- rep(1:500,each=2)
set.seed(345)
X <- matrix(rnorm(500 * 2 * 2), nrow=500 * 2, ncol=2)
alpha <-  tapply(X[,1],panelInd,mean) + rnorm(500)
y <- simu.panelMPL(X, panelInd, "truncReg",  beta=c(-1,2), sigma=1, alpha=alpha)
obj <- panelMPL(y~X, panel=panelInd, model="truncReg")  
summary(obj)  
## Compare MPL with MLE estimates
cbind(obj$mle, obj$est)
#
## AR(1)
panelInd <- rep(1:500,each=4)
set.seed(456)
X <- matrix(rnorm(500 * 4 * 2), nrow=500 * 4, ncol=2)
alpha <-  tapply(X[,1],panelInd,mean) + rnorm(500)
y <- simu.panelMPL(X, panelInd, "ar1",  beta=c(-1,2), sigma=1, rho=0.8, alpha=alpha)
obj <- panelMPL(y~X, panel=panelInd, model="ar1") 
summary(obj)  
## Compare MPL with MLE estimates
cbind(obj$mle, obj$est)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{models}
\keyword{regression}
